function [allocell, header]=read_affyannolist(fname, colorder)
% function [allocell, header]=read_affyannolist(fname, colorder)
% reads affymetrix annotation list.
% This is useful to get go biological process annotations for affymetrix
% gene ids. ignores leading rows until all colorder entries have been \
% found in one input line.
%
% IN
% fname  -  file name of a tab delimited text file.
% colorder - cell array of column orders
% 
% OUT
% allocell - cell array of strings describing contents.
% header  -  cell array of header line. 
%
% (C) P. Sykacek 2005, 2006
fid=fopen(fname, 'rt');
hdrstr=fgets(fid);
%fclose(fid);
found=0;
lcntr=1;
while (hdrstr~=-1) & (~found) & (lcntr <=8)
    ids=[0, find(hdrstr==sprintf('\t')), length(hdrstr)];
    ncols=length(ids)-1;
    header=cell(1, ncols);
    for n=1:ncols
      header{n}=hdrstr(ids(n)+1:ids(n+1)-1);
    end
    % get rid of potential leftower in a bad Win32 to Unix crlf
    % conversion.
    %header{ncols}=sscanf(header{ncols}, '%s', 1);

    % search for column order
    colids=zeros(1,length(colorder));
    found=1;
    for n =1:length(colorder)
        id=strmatch(colorder{n}, header);
        if ~isempty(id)
	   colids(n)=id;
	end
    end
    %hdrstr
    %header
    %colids
    found=~any(colids==0);
    if ~found
       hdrstr=fgets(fid);
    end
    lcntr=lcntr+1;
end
if ~found
    fclose(fid);
    error('Expected column names not found in header.');
end
allocell={};
line=fgets(fid);
%fclose(fid);

lcntr=1;
while line~=-1
    if mod(lcntr, 100)==0
      disp(sprintf('proc line: %1.0f', lcntr));
    end
    ids=[0, find(line==sprintf('\t')), length(line)];
    ncols=length(ids)-1;
    row=cell(1, ncols);
    for n=1:ncols
      row{n}=line(ids(n)+1:ids(n+1)-1);
    end
    % get rid of potential leftower in a bad Win32 to Unix crlf conversion. 
    %row{ncols}=sscanf(row{ncols}, '%s ', 1);
    line=fgets(fid);
    allocell=[allocell;row];
    lcntr=lcntr+1;		      
end
fclose(fid);
allocell=allocell(:, colids);
		      