function [genespec]=simpleaffygenesym(genespec, cutsymbol)
% function [genespec]=simpleaffygenesym(genespec, cutsymbol)
% simplifies the affymetrix annotation for gene symbols.
% every symbol is cut off before the first cutsymbol
% such that only one symbol remains. This is
% important to get short names. Default cutsymbol is
% '///' (which is the affy separator).
% 
% (C) P. Sykacek 2005

if nargin ==1
    cutsymbol='///';
end
if iscell(genespec{1})
    ncells=length(genespec);
    for n=1:ncelss
        tmp{:,n}=genespec{n};
    end
    genespec=tmp;
end
ngenes=size(genespec,1);
ncols=size(genespec, 2);
for n=1:ngenes
  for cno=1:ncols
    id=strfind(genespec{n, cno}, cutsymbol);
    if ~isempty(id)
      thisstr=genespec{n,cno};
      [tok, thisstr]=strtok(thisstr, cutsymbol);
      while ~isempty(thisstr) & ~isempty(strfind(tok, 'LOC'))
        [tok, thisstr]=strtok(thisstr, cutsymbol);            
      end
      while ~isempty(tok) & isspace(tok(1))
        tok=tok(2:length(tok));
      end
      genespec{n, cno}=tok;
    end
  end
end